@@ -54,7 +54,7 @@ class Wsdl(WsdlBase):
             # заголовок метода  Подготовить новую сборку
             'title': __("Prepare the New Build"),
             # иконка для графической консоли
-            'image': 'starred,rating,gtk-about',
+            'image': 'calculate-builder-prepare,starred,rating,gtk-about',
             # метод присутствует в графической консоли
             'gui': True,
             # консольная команда
@@ -105,7 +105,7 @@ class Wsdl(WsdlBase):
                            'cl_builder_disk_size',
                            ),
                     next_label=_("Next"))],
-            'brief': {'next': __("Perform"),
+            'brief': {'next': __("Run"),
                       'name': __("Prepare the New Build")},
         },
         {
@@ -116,7 +116,7 @@ class Wsdl(WsdlBase):
             # заголовок метода
             'title': __("Break the Build"),
             # иконка для графической консоли
-            'image': 'edit-clear',
+            'image': 'calculate-builder-break,edit-clear',
             # метод присутствует в графической консоли
             'gui': True,
             # консольная команда
@@ -141,8 +141,8 @@ class Wsdl(WsdlBase):
                                             'cl_builder_clear_set',
                                             'cl_builder_clear_pkg_set'),
                                     brief=('os_builder_linux_fullname',),
-                                    next_label=_("Perform"))],
-            'brief': {'next': __("Perform"),
+                                    next_label=_("Run"))],
+            'brief': {'next': __("Run"),
                       'name': __("Break the Build")},
         },
         {
@@ -153,7 +153,7 @@ class Wsdl(WsdlBase):
             # заголовок метода
             'title': __("Update the Build"),
             # иконка для графической консоли
-            'image': 'software-update-available,system-run',
+            'image': 'calculate-builder-update,software-update-available,system-run',
             # метод присутствует в графической консоли
             'gui': True,
             # консольная команда
@@ -239,7 +239,7 @@ class Wsdl(WsdlBase):
                         'cl_builder_brief_branch_data',
                     ),
                     next_label=_("Next"))],
-            'brief': {'next': __("Perform"),
+            'brief': {'next': __("Run"),
                       'name': __("Update the Build")}
         },
         {
@@ -250,7 +250,8 @@ class Wsdl(WsdlBase):
             # заголовок метода
             'title': __("Configure a Live-Menu"),
             # иконка для графической консоли
-            'image': 'format-indent-less-rtl,format-indent-more',
+            'image': 'calculate-update-livemenu,format-indent-less-rtl,'
+                     'format-indent-more',
             # метод присутствует в графической консоли
             'gui': True,
             # консольная команда
@@ -278,12 +279,13 @@ class Wsdl(WsdlBase):
                                         'cl_builder_locale_lang',
                                         'cl_builder_timezone',
                                         'cl_builder_x11_video_drv',
+                                        'cl_builder_audio',
                                         'cl_builder_x11_resolution',
                                         'cl_builder_x11_composite',
                                         'cl_builder_docache_set'
                                     ),
-                                    next_label=_("Perform"))],
-            'brief': {'next': __("Perform"),
+                                    next_label=_("Run"))],
+            'brief': {'next': __("Run"),
                       'name': __("Update Live-Menu")},
         },
         {
@@ -294,7 +296,8 @@ class Wsdl(WsdlBase):
             # заголовок метода
             'title': __("Restore the Build"),
             # иконка для графической консоли
-            'image': 'kt-restore-defaults,document-revert-rtl,'
+            'image': 'calculate-builder-restore,kt-restore-defaults,'
+                     'document-revert-rtl,'
                      'bookmark-new-list,document-revert',
             # метод присутствует в графической консоли
             'gui': True,
@@ -320,7 +323,7 @@ class Wsdl(WsdlBase):
                                     expert=('cl_templates_locate',
                                             'cl_verbose_set',
                                             'cl_dispatch_conf'),
-                                    next_label=_("Perform"))],
+                                    next_label=_("Run"))],
         },
         {
             # идентификатор метода
@@ -330,7 +333,7 @@ class Wsdl(WsdlBase):
             # заголовок метода
             'title': __("Create the Image"),
             # иконка для графической консоли
-            'image': 'media-optical,media-optical-data',
+            'image': 'calculate-builder-image,media-optical,media-optical-data',
             # метод присутствует в графической консоли
             'gui': True,
             # консольная команда
@@ -395,7 +398,7 @@ class Wsdl(WsdlBase):
                                         'cl_verbose_set',
                                         'cl_dispatch_conf'),
                                     next_label=_("Next"))],
-            'brief': {'next': __("Perform"),
+            'brief': {'next': __("Run"),
                       'name': __("Create the Image")}
         },
         #
@@ -409,7 +412,8 @@ class Wsdl(WsdlBase):
             # заголовок метода
             'title': __("Change the Build Profile"),
             # иконка для графической консоли
-            'image': 'notification-display-brightness-full,gtk-dialog-info,'
+            'image': 'calculate-builder-profile,'
+                     'notification-display-brightness-full,gtk-dialog-info,'
                      'help-hint',
             # метод присутствует в графической консоли
             'gui': True,
@@ -452,6 +456,6 @@ class Wsdl(WsdlBase):
                     brief=('cl_builder_profile_linux_fullname',
                            'cl_builder_profile_depend_data')
                 )],
-            'brief': {'next': __("Perform"),
+            'brief': {'next': __("Run"),
                       'name': __("Set the Profile")}},
     ]
